new — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »

# new

Wizard and wizard pages to assist in the creation of new objects

class `camelot.view.wizard.new.` `SelectSubclassPage`(parent, admin)

  Page for a wizard that allows the selection of a subclass

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »

Comments
blog comments powered by Disqus